@@ -1,7 +1,7 @@
 package Release::Util::Git;
 
-our $DATE = '2017-02-10'; # DATE
-our $VERSION = '0.004'; # VERSION
+our $DATE = '2019-10-24'; # DATE
+our $VERSION = '0.005'; # VERSION
 
 use 5.010001;
 use strict;
@@ -25,7 +25,7 @@ _
         regex => {
             summary => 'Regex to match a release tag',
             schema => 're*',
-            default => qr/\A(version|ver|v)?\d/,
+            default => qr/\A(?:(?:version|ver|v|release|rel)[_-]?)?\d/,
         },
         detail => {
             schema => ['bool*', is=>1],
@@ -137,7 +137,7 @@ Release::Util::Git - Utility routines related to software releases and git
 
 =head1 VERSION
 
-This document describes version 0.004 of Release::Util::Git (from Perl distribution Release-Util-Git), released on 2017-02-10.
+This document describes version 0.005 of Release::Util::Git (from Perl distribution Release-Util-Git), released on 2019-10-24.
 
 =head1 FUNCTIONS
 
@@ -146,7 +146,7 @@ This document describes version 0.004 of Release::Util::Git (from Perl distribut
 
 Usage:
 
- list_git_release_tags(%args) -> [status, msg, result, meta]
+ list_git_release_tags(%args) -> [status, msg, payload, meta]
 
 List git release tags.
 
@@ -185,18 +185,19 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
 Return value:  (any)
 
 
+
 =head2 list_git_release_years
 
 Usage:
 
- list_git_release_years(%args) -> [status, msg, result, meta]
+ list_git_release_years(%args) -> [status, msg, payload, meta]
 
 List git release years.
 
@@ -232,7 +233,7 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
@@ -260,7 +261,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
